@@ -26,6 +26,7 @@
     TriggerResource
     datafactory
     DataFlow
+    DataFlowResource
     mgmt
 """
 from __future__ import annotations
@@ -34,10 +35,9 @@ import inspect
 import time
 import warnings
 from functools import wraps
-from typing import TYPE_CHECKING, Any, Callable, TypeVar, Union, cast
+from typing import IO, TYPE_CHECKING, Any, Callable, TypeVar, Union, cast
 
 from asgiref.sync import sync_to_async
-from azure.core.exceptions import ServiceRequestError
 from azure.identity import ClientSecretCredential, DefaultAzureCredential
 from azure.identity.aio import (
     ClientSecretCredential as AsyncClientSecretCredential,
@@ -48,13 +48,12 @@ from azure.mgmt.datafactory.aio import DataFactoryManagementClient as AsyncDataF
 
 from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.hooks.base import BaseHook
-from airflow.typing_compat import TypedDict
 
 if TYPE_CHECKING:
     from azure.core.polling import LROPoller
     from azure.mgmt.datafactory.models import (
         CreateRunResponse,
-        DataFlow,
+        DataFlowResource,
         DatasetResource,
         Factory,
         LinkedServiceResource,
@@ -88,15 +87,9 @@ def provide_targeted_factory(func: Callable) -> Callable:
                 self = args[0]
                 conn = self.get_connection(self.conn_id)
                 extras = conn.extra_dejson
-                default_value = extras.get(default_key)
-                if not default_value and extras.get(f"extra__azure_data_factory__{default_key}"):
-                    warnings.warn(
-                        f"`extra__azure_data_factory__{default_key}` is deprecated in azure connection extra,"
-                        f" please use `{default_key}` instead",
-                        AirflowProviderDeprecationWarning,
-                        stacklevel=2,
-                    )
-                    default_value = extras.get(f"extra__azure_data_factory__{default_key}")
+                default_value = extras.get(default_key) or extras.get(
+                    f"extra__azure_data_factory__{default_key}"
+                )
                 if not default_value:
                     raise AirflowException("Could not determine the targeted data factory.")
 
@@ -110,14 +103,6 @@ def provide_targeted_factory(func: Callable) -> Callable:
     return wrapper
 
 
-class PipelineRunInfo(TypedDict):
-    """Type class for the pipeline run info dictionary."""
-
-    run_id: str
-    factory_name: str | None
-    resource_group_name: str | None
-
-
 class AzureDataFactoryPipelineRunStatus:
     """Azure Data Factory pipeline operation statuses."""
 
@@ -127,6 +112,7 @@ class AzureDataFactoryPipelineRunStatus:
     FAILED = "Failed"
     CANCELING = "Canceling"
     CANCELLED = "Cancelled"
+
     TERMINAL_STATUSES = {CANCELLED, FAILED, SUCCEEDED}
     INTERMEDIATE_STATES = {QUEUED, IN_PROGRESS, CANCELING}
     FAILURE_STATES = {FAILED, CANCELLED}
@@ -148,12 +134,6 @@ def get_field(extras: dict, field_name: str, strict: bool = False):
         return extras[field_name] or None
     prefixed_name = f"{backcompat_prefix}{field_name}"
     if prefixed_name in extras:
-        warnings.warn(
-            f"`{prefixed_name}` is deprecated in azure connection extra,"
-            f" please use `{field_name}` instead",
-            AirflowProviderDeprecationWarning,
-            stacklevel=2,
-        )
         return extras[prefixed_name] or None
     if strict:
         raise KeyError(f"Field {field_name} not found in extras")
@@ -199,7 +179,7 @@ class AzureDataFactoryHook(BaseHook):
         }
 
     def __init__(self, azure_data_factory_conn_id: str = default_conn_name):
-        self._conn: DataFactoryManagementClient = None
+        self._conn: DataFactoryManagementClient | None = None
         self.conn_id = azure_data_factory_conn_id
         super().__init__()
 
@@ -235,9 +215,7 @@ class AzureDataFactoryHook(BaseHook):
         return self.get_conn()
 
     @provide_targeted_factory
-    def get_factory(
-        self, resource_group_name: str | None = None, factory_name: str | None = None, **config: Any
-    ) -> Factory:
+    def get_factory(self, resource_group_name: str, factory_name: str, **config: Any) -> Factory | None:
         """
         Get the factory.
 
@@ -267,8 +245,9 @@ class AzureDataFactoryHook(BaseHook):
     def update_factory(
         self,
         factory: Factory,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
+        if_match: str | None = None,
         **config: Any,
     ) -> Factory:
         """
@@ -277,6 +256,8 @@ class AzureDataFactoryHook(BaseHook):
         :param factory: The factory resource definition.
         :param resource_group_name: The resource group name.
         :param factory_name: The factory name.
+        :param if_match: ETag of the factory entity. Should only be specified for update, for which it
+         should match existing entity or can be * for unconditional update. Default value is None.
         :param config: Extra parameters for the ADF client.
         :raise AirflowException: If the factory does not exist.
         :return: The factory.
@@ -285,15 +266,15 @@ class AzureDataFactoryHook(BaseHook):
             raise AirflowException(f"Factory {factory!r} does not exist.")
 
         return self.get_conn().factories.create_or_update(
-            resource_group_name, factory_name, factory, **config
+            resource_group_name, factory_name, factory, if_match, **config
         )
 
     @provide_targeted_factory
     def create_factory(
         self,
         factory: Factory,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> Factory:
         """
@@ -314,9 +295,7 @@ class AzureDataFactoryHook(BaseHook):
         )
 
     @provide_targeted_factory
-    def delete_factory(
-        self, resource_group_name: str | None = None, factory_name: str | None = None, **config: Any
-    ) -> None:
+    def delete_factory(self, resource_group_name: str, factory_name: str, **config: Any) -> None:
         """
         Delete the factory.
 
@@ -330,21 +309,25 @@ class AzureDataFactoryHook(BaseHook):
     def get_linked_service(
         self,
         linked_service_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
+        if_none_match: str | None = None,
         **config: Any,
-    ) -> LinkedServiceResource:
+    ) -> LinkedServiceResource | None:
         """
         Get the linked service.
 
         :param linked_service_name: The linked service name.
         :param resource_group_name: The resource group name.
         :param factory_name: The factory name.
+        :param if_none_match: ETag of the linked service entity. Should only be specified for get. If
+         the ETag matches the existing entity tag, or if * was provided, then no content will be
+         returned. Default value is None.
         :param config: Extra parameters for the ADF client.
         :return: The linked service.
         """
         return self.get_conn().linked_services.get(
-            resource_group_name, factory_name, linked_service_name, **config
+            resource_group_name, factory_name, linked_service_name, if_none_match, **config
         )
 
     def _linked_service_exists(self, resource_group_name, factory_name, linked_service_name) -> bool:
@@ -363,8 +346,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         linked_service_name: str,
         linked_service: LinkedServiceResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> LinkedServiceResource:
         """
@@ -390,8 +373,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         linked_service_name: str,
         linked_service: LinkedServiceResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> LinkedServiceResource:
         """
@@ -416,8 +399,8 @@ class AzureDataFactoryHook(BaseHook):
     def delete_linked_service(
         self,
         linked_service_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -436,10 +419,10 @@ class AzureDataFactoryHook(BaseHook):
     def get_dataset(
         self,
         dataset_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
-    ) -> DatasetResource:
+    ) -> DatasetResource | None:
         """
         Get the dataset.
 
@@ -465,8 +448,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         dataset_name: str,
         dataset: DatasetResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> DatasetResource:
         """
@@ -492,8 +475,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         dataset_name: str,
         dataset: DatasetResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> DatasetResource:
         """
@@ -518,8 +501,8 @@ class AzureDataFactoryHook(BaseHook):
     def delete_dataset(
         self,
         dataset_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -536,26 +519,32 @@ class AzureDataFactoryHook(BaseHook):
     def get_dataflow(
         self,
         dataflow_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
+        if_none_match: str | None = None,
         **config: Any,
-    ) -> DataFlow:
+    ) -> DataFlowResource:
         """
         Get the dataflow.
 
         :param dataflow_name: The dataflow name.
         :param resource_group_name: The resource group name.
         :param factory_name: The factory name.
+        :param if_none_match: ETag of the data flow entity. Should only be specified for get. If the
+         ETag matches the existing entity tag, or if * was provided, then no content will be returned.
+         Default value is None.
         :param config: Extra parameters for the ADF client.
-        :return: The dataflow.
+        :return: The DataFlowResource.
         """
-        return self.get_conn().data_flows.get(resource_group_name, factory_name, dataflow_name, **config)
+        return self.get_conn().data_flows.get(
+            resource_group_name, factory_name, dataflow_name, if_none_match, **config
+        )
 
     def _dataflow_exists(
         self,
         dataflow_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
     ) -> bool:
         """Return whether the dataflow already exists."""
         dataflows = {
@@ -569,11 +558,12 @@ class AzureDataFactoryHook(BaseHook):
     def update_dataflow(
         self,
         dataflow_name: str,
-        dataflow: DataFlow,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        dataflow: DataFlowResource | IO,
+        resource_group_name: str,
+        factory_name: str,
+        if_match: str | None = None,
         **config: Any,
-    ) -> DataFlow:
+    ) -> DataFlowResource:
         """
         Update the dataflow.
 
@@ -581,9 +571,11 @@ class AzureDataFactoryHook(BaseHook):
         :param dataflow: The dataflow resource definition.
         :param resource_group_name: The resource group name.
         :param factory_name: The factory name.
+        :param if_match: ETag of the data flow entity. Should only be specified for update, for which
+         it should match existing entity or can be * for unconditional update. Default value is None.
         :param config: Extra parameters for the ADF client.
         :raise AirflowException: If the dataset does not exist.
-        :return: The dataflow.
+        :return: DataFlowResource.
         """
         if not self._dataflow_exists(
             dataflow_name,
@@ -593,18 +585,19 @@ class AzureDataFactoryHook(BaseHook):
             raise AirflowException(f"Dataflow {dataflow_name!r} does not exist.")
 
         return self.get_conn().data_flows.create_or_update(
-            resource_group_name, factory_name, dataflow_name, dataflow, **config
+            resource_group_name, factory_name, dataflow_name, dataflow, if_match, **config
         )
 
     @provide_targeted_factory
     def create_dataflow(
         self,
         dataflow_name: str,
-        dataflow: DataFlow,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        dataflow: DataFlowResource,
+        resource_group_name: str,
+        factory_name: str,
+        if_match: str | None = None,
         **config: Any,
-    ) -> DataFlow:
+    ) -> DataFlowResource:
         """
         Create the dataflow.
 
@@ -612,6 +605,8 @@ class AzureDataFactoryHook(BaseHook):
         :param dataflow: The dataflow resource definition.
         :param resource_group_name: The resource group name.
         :param factory_name: The factory name.
+        :param if_match: ETag of the factory entity. Should only be specified for update, for which it
+         should match existing entity or can be * for unconditional update. Default value is None.
         :param config: Extra parameters for the ADF client.
         :raise AirflowException: If the dataset already exists.
         :return: The dataset.
@@ -620,15 +615,15 @@ class AzureDataFactoryHook(BaseHook):
             raise AirflowException(f"Dataflow {dataflow_name!r} already exists.")
 
         return self.get_conn().data_flows.create_or_update(
-            resource_group_name, factory_name, dataflow_name, dataflow, **config
+            resource_group_name, factory_name, dataflow_name, dataflow, if_match, **config
         )
 
     @provide_targeted_factory
     def delete_dataflow(
         self,
         dataflow_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -645,10 +640,10 @@ class AzureDataFactoryHook(BaseHook):
     def get_pipeline(
         self,
         pipeline_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
-    ) -> PipelineResource:
+    ) -> PipelineResource | None:
         """
         Get the pipeline.
 
@@ -674,8 +669,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         pipeline_name: str,
         pipeline: PipelineResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> PipelineResource:
         """
@@ -701,8 +696,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         pipeline_name: str,
         pipeline: PipelineResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> PipelineResource:
         """
@@ -727,8 +722,8 @@ class AzureDataFactoryHook(BaseHook):
     def delete_pipeline(
         self,
         pipeline_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -745,8 +740,8 @@ class AzureDataFactoryHook(BaseHook):
     def run_pipeline(
         self,
         pipeline_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> CreateRunResponse:
         """
@@ -766,8 +761,8 @@ class AzureDataFactoryHook(BaseHook):
     def get_pipeline_run(
         self,
         run_id: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> PipelineRun:
         """
@@ -784,8 +779,8 @@ class AzureDataFactoryHook(BaseHook):
     def get_pipeline_run_status(
         self,
         run_id: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
     ) -> str:
         """
         Get a pipeline run's current status.
@@ -796,11 +791,7 @@ class AzureDataFactoryHook(BaseHook):
         :return: The status of the pipeline run.
         """
         self.log.info("Getting the status of run ID %s.", run_id)
-        pipeline_run_status = self.get_pipeline_run(
-            run_id=run_id,
-            factory_name=factory_name,
-            resource_group_name=resource_group_name,
-        ).status
+        pipeline_run_status = self.get_pipeline_run(run_id, resource_group_name, factory_name).status
         self.log.info("Current status of pipeline run %s: %s", run_id, pipeline_run_status)
 
         return pipeline_run_status
@@ -809,8 +800,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         run_id: str,
         expected_statuses: str | set[str],
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         check_interval: int = 60,
         timeout: int = 60 * 60 * 24 * 7,
     ) -> bool:
@@ -826,13 +817,7 @@ class AzureDataFactoryHook(BaseHook):
             status.
         :return: Boolean indicating if the pipeline run has reached the ``expected_status``.
         """
-        pipeline_run_info = PipelineRunInfo(
-            run_id=run_id,
-            factory_name=factory_name,
-            resource_group_name=resource_group_name,
-        )
-        pipeline_run_status = self.get_pipeline_run_status(**pipeline_run_info)
-        executed_after_token_refresh = True
+        pipeline_run_status = self.get_pipeline_run_status(run_id, resource_group_name, factory_name)
 
         start_time = time.monotonic()
 
@@ -849,14 +834,7 @@ class AzureDataFactoryHook(BaseHook):
             # Wait to check the status of the pipeline run based on the ``check_interval`` configured.
             time.sleep(check_interval)
 
-            try:
-                pipeline_run_status = self.get_pipeline_run_status(**pipeline_run_info)
-                executed_after_token_refresh = True
-            except ServiceRequestError:
-                if executed_after_token_refresh:
-                    self.refresh_conn()
-                else:
-                    raise
+            pipeline_run_status = self.get_pipeline_run_status(run_id, resource_group_name, factory_name)
 
         return pipeline_run_status in expected_statuses
 
@@ -864,8 +842,8 @@ class AzureDataFactoryHook(BaseHook):
     def cancel_pipeline_run(
         self,
         run_id: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -882,10 +860,10 @@ class AzureDataFactoryHook(BaseHook):
     def get_trigger(
         self,
         trigger_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
-    ) -> TriggerResource:
+    ) -> TriggerResource | None:
         """
         Get the trigger.
 
@@ -911,8 +889,9 @@ class AzureDataFactoryHook(BaseHook):
         self,
         trigger_name: str,
         trigger: TriggerResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
+        if_match: str | None = None,
         **config: Any,
     ) -> TriggerResource:
         """
@@ -922,6 +901,8 @@ class AzureDataFactoryHook(BaseHook):
         :param trigger: The trigger resource definition.
         :param resource_group_name: The resource group name.
         :param factory_name: The factory name.
+        :param if_match: ETag of the trigger entity.  Should only be specified for update, for which it
+         should match existing entity or can be * for unconditional update. Default value is None.
         :param config: Extra parameters for the ADF client.
         :raise AirflowException: If the trigger does not exist.
         :return: The trigger.
@@ -930,7 +911,7 @@ class AzureDataFactoryHook(BaseHook):
             raise AirflowException(f"Trigger {trigger_name!r} does not exist.")
 
         return self.get_conn().triggers.create_or_update(
-            resource_group_name, factory_name, trigger_name, trigger, **config
+            resource_group_name, factory_name, trigger_name, trigger, if_match, **config
         )
 
     @provide_targeted_factory
@@ -938,8 +919,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         trigger_name: str,
         trigger: TriggerResource,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> TriggerResource:
         """
@@ -964,8 +945,8 @@ class AzureDataFactoryHook(BaseHook):
     def delete_trigger(
         self,
         trigger_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -982,8 +963,8 @@ class AzureDataFactoryHook(BaseHook):
     def start_trigger(
         self,
         trigger_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> LROPoller:
         """
@@ -1001,8 +982,8 @@ class AzureDataFactoryHook(BaseHook):
     def stop_trigger(
         self,
         trigger_name: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> LROPoller:
         """
@@ -1021,8 +1002,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         trigger_name: str,
         run_id: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -1043,8 +1024,8 @@ class AzureDataFactoryHook(BaseHook):
         self,
         trigger_name: str,
         run_id: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
@@ -1068,7 +1049,7 @@ class AzureDataFactoryHook(BaseHook):
             # DataFactoryManagementClient with incorrect values but then will fail properly once items are
             # retrieved using the client. We need to _actually_ try to retrieve an object to properly test the
             # connection.
-            next(self.get_conn().factories.list())
+            self.get_conn().factories.list()
             return success
         except StopIteration:
             # If the iterator returned is empty it should still be considered a successful connection since
@@ -1132,7 +1113,7 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
     default_conn_name: str = "azure_data_factory_default"
 
     def __init__(self, azure_data_factory_conn_id: str = default_conn_name):
-        self._async_conn: AsyncDataFactoryManagementClient = None
+        self._async_conn: AsyncDataFactoryManagementClient | None = None
         self.conn_id = azure_data_factory_conn_id
         super().__init__(azure_data_factory_conn_id=azure_data_factory_conn_id)
 
@@ -1168,7 +1149,7 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
 
         return self._async_conn
 
-    async def refresh_conn(self) -> AsyncDataFactoryManagementClient:
+    async def refresh_conn(self) -> AsyncDataFactoryManagementClient:  # type: ignore[override]
         self._conn = None
         return await self.get_async_conn()
 
@@ -1176,8 +1157,8 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
     async def get_pipeline_run(
         self,
         run_id: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> PipelineRun:
         """
@@ -1193,7 +1174,7 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
         return pipeline_run
 
     async def get_adf_pipeline_run_status(
-        self, run_id: str, resource_group_name: str | None = None, factory_name: str | None = None
+        self, run_id: str, resource_group_name: str, factory_name: str
     ) -> str:
         """
         Connect to Azure Data Factory asynchronously and get the pipeline status by run_id.
@@ -1202,20 +1183,16 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
         :param resource_group_name: The resource group name.
         :param factory_name: The factory name.
         """
-        pipeline_run = await self.get_pipeline_run(
-            run_id=run_id,
-            factory_name=factory_name,
-            resource_group_name=resource_group_name,
-        )
-        status: str = pipeline_run.status
+        pipeline_run = await self.get_pipeline_run(run_id, resource_group_name, factory_name)
+        status: str = cast(str, pipeline_run.status)
         return status
 
     @provide_targeted_factory_async
     async def cancel_pipeline_run(
         self,
         run_id: str,
-        resource_group_name: str | None = None,
-        factory_name: str | None = None,
+        resource_group_name: str,
+        factory_name: str,
         **config: Any,
     ) -> None:
         """
