@@ -16,14 +16,15 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
-from azure.synapse.spark.models import SparkBatchJobOptions
-
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.synapse import AzureSynapseHook, AzureSynapseSparkBatchRunStatus
 
 if TYPE_CHECKING:
+    from azure.synapse.spark.models import SparkBatchJobOptions
+
     from airflow.utils.context import Context
 
 
@@ -58,7 +59,7 @@ class AzureSynapseRunSparkBatchOperator(BaseOperator):
         *,
         azure_synapse_conn_id: str = AzureSynapseHook.default_conn_name,
         wait_for_termination: bool = True,
-        spark_pool: str = '',
+        spark_pool: str = "",
         payload: SparkBatchJobOptions,
         timeout: int = 60 * 60 * 24 * 7,
         check_interval: int = 60,
@@ -73,10 +74,12 @@ class AzureSynapseRunSparkBatchOperator(BaseOperator):
         self.timeout = timeout
         self.check_interval = check_interval
 
+    @cached_property
+    def hook(self):
+        """Create and return an AzureSynapseHook (cached)."""
+        return AzureSynapseHook(azure_synapse_conn_id=self.azure_synapse_conn_id, spark_pool=self.spark_pool)
+
     def execute(self, context: Context) -> None:
-        self.hook = AzureSynapseHook(
-            azure_synapse_conn_id=self.azure_synapse_conn_id, spark_pool=self.spark_pool
-        )
         self.log.info("Executing the Synapse spark job.")
         response = self.hook.run_spark_job(payload=self.payload)
         self.log.info(response)
