@@ -23,7 +23,7 @@ import warnings
 from functools import cached_property
 
 from azure.core.exceptions import ResourceNotFoundError
-from azure.identity import DefaultAzureCredential
+from azure.identity import ClientSecretCredential, DefaultAzureCredential
 from azure.keyvault.secrets import SecretClient
 
 from airflow.exceptions import AirflowProviderDeprecationWarning
@@ -72,6 +72,12 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
         If set to None (null), requests for configurations will not be sent to Azure Key Vault
     :param vault_url: The URL of an Azure Key Vault to use
     :param sep: separator used to concatenate secret_prefix and secret_id. Default: "-"
+    :param tenant_id: The tenant id of an Azure Key Vault to use.
+        If not given, it falls back to ``DefaultAzureCredential``
+    :param client_id: The client id of an Azure Key Vault to use.
+        If not given, it falls back to ``DefaultAzureCredential``
+    :param client_secret: The client secret of an Azure Key Vault to use.
+        If not given, it falls back to ``DefaultAzureCredential``
     """
 
     def __init__(
@@ -81,6 +87,10 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
         config_prefix: str = "airflow-config",
         vault_url: str = "",
         sep: str = "-",
+        *,
+        tenant_id: str = "",
+        client_id: str = "",
+        client_secret: str = "",
         **kwargs,
     ) -> None:
         super().__init__()
@@ -105,12 +115,19 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
             logger.setLevel(logging.WARNING)
 
         self.sep = sep
+        self.tenant_id = tenant_id
+        self.client_id = client_id
+        self.client_secret = client_secret
         self.kwargs = kwargs
 
     @cached_property
     def client(self) -> SecretClient:
         """Create a Azure Key Vault client."""
-        credential = DefaultAzureCredential()
+        credential: ClientSecretCredential | DefaultAzureCredential
+        if all([self.tenant_id, self.client_id, self.client_secret]):
+            credential = ClientSecretCredential(self.tenant_id, self.client_id, self.client_secret)
+        else:
+            credential = DefaultAzureCredential()
         client = SecretClient(vault_url=self.vault_url, credential=credential, **self.kwargs)
         return client
 
